import _extends from '@babel/runtime/helpers/extends';
import _objectWithoutProperties from '@babel/runtime/helpers/objectWithoutProperties';
import PropTypes from 'prop-types';
import React from 'react';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _assertThisInitialized from '@babel/runtime/helpers/assertThisInitialized';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import _defineProperty from '@babel/runtime/helpers/defineProperty';
import * as Mobiledoc from 'mobiledoc-kit';
import { UI } from 'mobiledoc-kit';
import ReactDOM from 'react-dom';

const titleCase = (function (str) {
  return "".concat(str.charAt(0).toUpperCase()).concat(str.slice(1));
});

const getActiveAttribute = (function (activeSectionAttributes, attribute, defaultValue) {
  var attributes = activeSectionAttributes.map(function (a) {
    return a["data-md-".concat(attribute)] || defaultValue;
  });
  var activeAttribute = attributes[0];

  for (var i = 1; i < attributes.length; i++) {
    if (activeAttribute !== attributes[i]) {
      activeAttribute = '';
      break;
    }
  }

  return activeAttribute;
});

var ReactMobileDocContext = /*#__PURE__*/React.createContext({});
ReactMobileDocContext.displayName = 'ReactMobileDocContext';

var _excluded$6 = ["values", "defaultValue", "attribute"];

var AttributeSelect = function AttributeSelect(_ref) {
  var _ref$values = _ref.values,
      values = _ref$values === void 0 ? [] : _ref$values,
      _ref$defaultValue = _ref.defaultValue,
      defaultValue = _ref$defaultValue === void 0 ? values[0] : _ref$defaultValue,
      attribute = _ref.attribute,
      props = _objectWithoutProperties(_ref, _excluded$6);

  return /*#__PURE__*/React.createElement(ReactMobileDocContext.Consumer, null, function (_ref2) {
    var editor = _ref2.editor,
        _ref2$activeSectionAt = _ref2.activeSectionAttributes,
        activeSectionAttributes = _ref2$activeSectionAt === void 0 ? [] : _ref2$activeSectionAt;
    var activeAttribute = getActiveAttribute(activeSectionAttributes, attribute, defaultValue);

    var onChange = function onChange(event) {
      var value = event.target.value;

      if (value === defaultValue) {
        editor.removeAttribute(attribute);
      } else {
        editor.setAttribute(attribute, value);
      }
    };

    return /*#__PURE__*/React.createElement("select", _extends({
      value: activeAttribute,
      onChange: onChange
    }, props), activeAttribute === '' && /*#__PURE__*/React.createElement("option", {
      value: '',
      key: ''
    }, "\u2014"), values.map(function (v) {
      return /*#__PURE__*/React.createElement("option", {
        value: v,
        key: v
      }, titleCase(v));
    }));
  });
};

AttributeSelect.propTypes = {
  attribute: PropTypes.string.isRequired,
  values: PropTypes.arrayOf(PropTypes.string).isRequired
};

var LATEST_MOBILEDOC_VERSION = '0.3.2';
var EMPTY_MOBILEDOC = {
  version: LATEST_MOBILEDOC_VERSION,
  markups: [],
  atoms: [],
  cards: [],
  sections: [[1, 'p', []]]
};

var _excluded$5 = ["atoms", "autofocus", "cardProps", "cards", "children", "didCreateEditor", "html", "mobiledoc", "options", "placeholder", "serializeVersion", "spellcheck", "willCreateEditor", "onChange", "createRoot"];

function ownKeys$5(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$5(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$5(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$5(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _createSuper$1(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct$1(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct$1() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var Container = /*#__PURE__*/function (_React$Component) {
  _inherits(Container, _React$Component);

  var _super = _createSuper$1(Container);

  function Container() {
    var _this;

    _classCallCheck(this, Container);

    _this = _super.apply(this, arguments);

    _defineProperty(_assertThisInitialized(_this), "state", {
      activeMarkupTags: [],
      activeSectionTags: [],
      activeSectionAttributes: []
    });

    _defineProperty(_assertThisInitialized(_this), "setActiveTags", function () {
      _this.setState({
        activeSectionAttributes: _this.editor.activeSections.map(function (s) {
          return s.attributes || {};
        }),
        activeMarkupTags: _this.editor.activeMarkups.map(function (m) {
          return m.tagName;
        }),
        // editor.activeSections are leaf sections.
        // Map parent section tag names (e.g. 'p', 'ul', 'ol') so that list buttons
        // are updated.
        activeSectionTags: _this.editor.activeSections.map(function (s) {
          return s.isNested ? s.parent.tagName : s.tagName;
        })
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleChange", function () {
      if (typeof _this.props.onChange === 'function') {
        var mobiledoc = _this.editor.serialize(_this.props.serializeVersion);

        _this.props.onChange(mobiledoc);
      }
    });

    if (typeof _this.props.willCreateEditor === 'function') {
      _this.props.willCreateEditor();
    }

    var _this$props = _this.props,
        atoms = _this$props.atoms,
        autofocus = _this$props.autofocus,
        cardProps = _this$props.cardProps,
        cards = _this$props.cards,
        html = _this$props.html,
        placeholder = _this$props.placeholder,
        serializeVersion = _this$props.serializeVersion,
        spellcheck = _this$props.spellcheck,
        createRoot = _this$props.createRoot;

    var _mobiledoc = _this.props.mobiledoc || (html ? undefined : EMPTY_MOBILEDOC);

    var editorOptions = _objectSpread$5(_objectSpread$5({}, _this.props.options), {}, {
      atoms: atoms,
      autofocus: autofocus,
      cardOptions: {
        cardProps: cardProps,
        createRoot: createRoot
      },
      cards: cards,
      html: html,
      mobiledoc: _mobiledoc,
      placeholder: placeholder,
      serializeVersion: serializeVersion,
      spellcheck: spellcheck
    });

    _this.editor = new Mobiledoc.Editor(editorOptions);

    _this.editor.inputModeDidChange(_this.setActiveTags);

    _this.editor.postDidChange(function () {
      _this.handleChange();
    });

    if (typeof _this.props.didCreateEditor === 'function') {
      _this.props.didCreateEditor(_this.editor);
    }

    return _this;
  }

  _createClass(Container, [{
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.editor.destroy();
    }
  }, {
    key: "render",
    value: function render() {
      /* eslint-disable no-unused-vars */

      /* deconstruct out non-React props before passing to children */
      var _this$props2 = this.props;
          _this$props2.atoms;
          _this$props2.autofocus;
          _this$props2.cardProps;
          _this$props2.cards;
          var children = _this$props2.children;
          _this$props2.didCreateEditor;
          _this$props2.html;
          _this$props2.mobiledoc;
          _this$props2.options;
          _this$props2.placeholder;
          _this$props2.serializeVersion;
          _this$props2.spellcheck;
          _this$props2.willCreateEditor;
          _this$props2.onChange;
          _this$props2.createRoot;
          var componentProps = _objectWithoutProperties(_this$props2, _excluded$5);
      /* eslint-enable no-unused-vars */


      return /*#__PURE__*/React.createElement("div", componentProps, /*#__PURE__*/React.createElement(ReactMobileDocContext.Provider, {
        value: {
          editor: this.editor,
          activeMarkupTags: this.state.activeMarkupTags,
          activeSectionTags: this.state.activeSectionTags,
          activeSectionAttributes: this.state.activeSectionAttributes
        }
      }, children));
    }
  }]);

  return Container;
}(React.Component);

_defineProperty(Container, "defaultProps", {
  atoms: [],
  autofocus: true,
  cardProps: {},
  cards: [],
  placeholder: '',
  serializeVersion: LATEST_MOBILEDOC_VERSION,
  spellcheck: true
});

Container.propTypes = {
  atoms: PropTypes.array,
  autofocus: PropTypes.bool,
  cards: PropTypes.array,
  didCreateEditor: PropTypes.func,
  html: PropTypes.string,
  mobiledoc: PropTypes.object,
  onChange: PropTypes.func,
  options: PropTypes.object,
  placeholder: PropTypes.string,
  serializeVersion: PropTypes.string,
  spellcheck: PropTypes.bool,
  willCreateEditor: PropTypes.func
};

var _excluded$4 = ["context"];

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

var Editor = /*#__PURE__*/function (_React$Component) {
  _inherits(Editor, _React$Component);

  var _super = _createSuper(Editor);

  function Editor() {
    _classCallCheck(this, Editor);

    return _super.apply(this, arguments);
  }

  _createClass(Editor, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var editor = this.props.context.editor;

      if (editor) {
        editor.render(this.editorEl);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this = this;

      // eslint-disable-next-line no-unused-vars
      var _this$props = this.props;
          _this$props.context;
          var props = _objectWithoutProperties(_this$props, _excluded$4);

      return /*#__PURE__*/React.createElement("div", _extends({}, props, {
        ref: function ref(r) {
          return _this.editorEl = r;
        }
      }));
    }
  }]);

  return Editor;
}(React.Component);

var EditorOuter = /*#__PURE__*/React.forwardRef(function EditorOuter(props, ref) {
  return /*#__PURE__*/React.createElement(ReactMobileDocContext.Consumer, null, function (context) {
    return /*#__PURE__*/React.createElement(Editor, _extends({}, props, {
      context: context,
      ref: ref
    }));
  });
});

var _excluded$3 = ["children", "type", "handler", "className", "activeClassName"];

function ownKeys$4(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$4(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$4(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$4(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

var LinkButton = function LinkButton(_ref) {
  var _ref$children = _ref.children,
      children = _ref$children === void 0 ? 'Link' : _ref$children,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'button' : _ref$type,
      handler = _ref.handler,
      className = _ref.className,
      _ref$activeClassName = _ref.activeClassName,
      activeClassName = _ref$activeClassName === void 0 ? 'active' : _ref$activeClassName,
      props = _objectWithoutProperties(_ref, _excluded$3);

  return /*#__PURE__*/React.createElement(ReactMobileDocContext.Consumer, null, function (_ref2) {
    var editor = _ref2.editor,
        _ref2$activeMarkupTag = _ref2.activeMarkupTags,
        activeMarkupTags = _ref2$activeMarkupTag === void 0 ? [] : _ref2$activeMarkupTag;

    var onClick = function onClick() {
      if (!editor.hasCursor()) {
        return;
      }

      if (editor.hasActiveMarkup('a')) {
        editor.toggleMarkup('a');
      } else {
        UI.toggleLink(editor, handler);
      }
    };

    className = [className, activeMarkupTags.indexOf('a') > -1 && activeClassName].filter(Boolean).join(' ');
    props = _objectSpread$4(_objectSpread$4({
      type: type
    }, props), {}, {
      onClick: onClick,
      className: className
    });
    return /*#__PURE__*/React.createElement("button", props, children);
  });
};

LinkButton.propTypes = {
  children: PropTypes.node
};

var _excluded$2 = ["tag", "type", "children", "className", "activeClassName"];

function ownKeys$3(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$3(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$3(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$3(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

var MarkupButton = function MarkupButton(_ref) {
  var _ref$tag = _ref.tag,
      tag = _ref$tag === void 0 ? '' : _ref$tag,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'button' : _ref$type,
      _ref$children = _ref.children,
      children = _ref$children === void 0 ? titleCase(tag) : _ref$children,
      className = _ref.className,
      _ref$activeClassName = _ref.activeClassName,
      activeClassName = _ref$activeClassName === void 0 ? 'active' : _ref$activeClassName,
      props = _objectWithoutProperties(_ref, _excluded$2);

  return /*#__PURE__*/React.createElement(ReactMobileDocContext.Consumer, null, function (_ref2) {
    var editor = _ref2.editor,
        _ref2$activeMarkupTag = _ref2.activeMarkupTags,
        activeMarkupTags = _ref2$activeMarkupTag === void 0 ? [] : _ref2$activeMarkupTag;

    var onClick = function onClick() {
      return editor.toggleMarkup(tag);
    };

    className = [className, activeMarkupTags.indexOf(tag.toLowerCase()) > -1 && activeClassName].filter(Boolean).join(' ');
    props = _objectSpread$3(_objectSpread$3({
      type: type
    }, props), {}, {
      onClick: onClick,
      className: className
    });
    return /*#__PURE__*/React.createElement("button", props, children);
  });
};

MarkupButton.propTypes = {
  tag: PropTypes.string.isRequired,
  children: PropTypes.node
};

var _excluded$1 = ["tag", "type", "children", "className", "activeClassName"];

function ownKeys$2(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$2(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$2(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$2(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

var SectionButton = function SectionButton(_ref) {
  var _ref$tag = _ref.tag,
      tag = _ref$tag === void 0 ? '' : _ref$tag,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'button' : _ref$type,
      _ref$children = _ref.children,
      children = _ref$children === void 0 ? titleCase(tag) : _ref$children,
      className = _ref.className,
      _ref$activeClassName = _ref.activeClassName,
      activeClassName = _ref$activeClassName === void 0 ? 'active' : _ref$activeClassName,
      props = _objectWithoutProperties(_ref, _excluded$1);

  return /*#__PURE__*/React.createElement(ReactMobileDocContext.Consumer, null, function (_ref2) {
    var editor = _ref2.editor,
        _ref2$activeSectionTa = _ref2.activeSectionTags,
        activeSectionTags = _ref2$activeSectionTa === void 0 ? [] : _ref2$activeSectionTa;

    var onClick = function onClick() {
      return editor.toggleSection(tag);
    };

    className = [className, activeSectionTags.indexOf(tag.toLowerCase()) > -1 && activeClassName].filter(Boolean).join(' ');
    props = _objectSpread$2(_objectSpread$2({
      type: type
    }, props), {}, {
      onClick: onClick,
      className: className
    });
    return /*#__PURE__*/React.createElement("button", props, children);
  });
};

SectionButton.propTypes = {
  tag: PropTypes.string.isRequired,
  children: PropTypes.node
};

var _excluded = ["tags"];

var SectionSelect = function SectionSelect(_ref) {
  var _ref$tags = _ref.tags,
      tags = _ref$tags === void 0 ? [] : _ref$tags,
      props = _objectWithoutProperties(_ref, _excluded);

  return /*#__PURE__*/React.createElement(ReactMobileDocContext.Consumer, null, function (_ref2) {
    var editor = _ref2.editor,
        _ref2$activeSectionTa = _ref2.activeSectionTags,
        activeSectionTags = _ref2$activeSectionTa === void 0 ? [] : _ref2$activeSectionTa;

    var activeTag = function activeTag() {
      return tags.find(function (t) {
        return activeSectionTags.includes(t);
      });
    };

    var onChange = function onChange(event) {
      var tag = event.target.value || activeTag();
      editor.toggleSection(tag);
    };

    return /*#__PURE__*/React.createElement("select", _extends({
      value: activeTag() || '',
      onChange: onChange
    }, props), /*#__PURE__*/React.createElement("option", {
      value: ""
    }), tags.map(function (t) {
      return /*#__PURE__*/React.createElement("option", {
        value: t,
        key: t
      }, t.toUpperCase());
    }));
  });
};

SectionSelect.propTypes = {
  tags: PropTypes.arrayOf(PropTypes.oneOf(['p', 'h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'blockquote', 'aside'])).isRequired
};

var Toolbar = function Toolbar(props) {
  return /*#__PURE__*/React.createElement("ul", props, /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement(MarkupButton, {
    tag: "strong"
  })), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement(MarkupButton, {
    tag: "em"
  })), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement(LinkButton, null)), /*#__PURE__*/React.createElement("li", null, "Style: ", /*#__PURE__*/React.createElement(SectionSelect, {
    tags: ['h1', 'h2', 'h3']
  })), /*#__PURE__*/React.createElement("li", null, "Alignment:", ' ', /*#__PURE__*/React.createElement(AttributeSelect, {
    attribute: "text-align",
    values: ['left', 'center', 'right']
  })), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement(SectionButton, {
    tag: "blockquote"
  })), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement(SectionButton, {
    tag: "ul"
  }, "UL")), /*#__PURE__*/React.createElement("li", null, /*#__PURE__*/React.createElement(SectionButton, {
    tag: "ol"
  }, "OL")));
};

function reactDomRender(createRoot, element, target) {
  // React 18+
  if (createRoot) {
    var root = createRoot(target);
    root.render(element);
    return root;
  } else {
    ReactDOM.render(element, target);
  }
}
function reactDomUnmount(root, target) {
  if (root) root.unmount();else ReactDOM.unmountComponentAtNode(target);
}

function ownKeys$1(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread$1(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys$1(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys$1(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

var atomRenderer = function atomRenderer(component) {
  return function (_ref) {
    var env = _ref.env,
        options = _ref.options,
        payload = _ref.payload,
        value = _ref.value;
    var onTeardown = env.onTeardown;
    var createRoot = options.createRoot;
    var element = /*#__PURE__*/React.createElement(component, _objectSpread$1(_objectSpread$1(_objectSpread$1({}, env), options), {}, {
      value: value,
      payload: _objectSpread$1({}, payload)
    }));
    var targetNode = document.createElement('span');
    var root = reactDomRender(createRoot, element, targetNode);
    onTeardown(function () {
      return reactDomUnmount(root, targetNode);
    });
    return targetNode;
  };
};

var classToDOMAtom = function classToDOMAtom(component) {
  if (!component.displayName) {
    throw new Error("Can't create atom from component, no displayName defined: ".concat(component));
  }

  return {
    name: component.displayName,
    component: component,
    type: 'dom',
    render: atomRenderer(component)
  };
};

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

var cardRenderer = function cardRenderer(component) {
  var isEditing = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  return function (_ref) {
    var env = _ref.env,
        options = _ref.options,
        payload = _ref.payload;
    var targetNode = document.createElement('div');
    var didRender = env.didRender,
        onTeardown = env.onTeardown;
    var cardProps = options.cardProps,
        createRoot = options.createRoot;
    var root;
    didRender(function () {
      payload = _objectSpread({}, payload); // deref payload

      var element = /*#__PURE__*/React.createElement(component, _objectSpread(_objectSpread(_objectSpread({}, env), cardProps), {}, {
        payload: payload,
        isEditing: isEditing
      }));
      root = reactDomRender(createRoot, element, targetNode);
    });
    onTeardown(function () {
      return reactDomUnmount(root, targetNode);
    });
    return targetNode;
  };
};

var classToDOMCard = function classToDOMCard(component) {
  if (!component.displayName) {
    throw new Error("Can't create card from component, no displayName defined: " + component);
  }

  return {
    name: component.displayName,
    component: component,
    type: 'dom',
    render: cardRenderer(component),
    edit: cardRenderer(component, true)
  };
};

export { AttributeSelect, Container, EMPTY_MOBILEDOC, EditorOuter as Editor, LinkButton, MarkupButton, ReactMobileDocContext, SectionButton, SectionSelect, Toolbar, classToDOMAtom, classToDOMCard };
//# sourceMappingURL=react-mobiledoc-editor.esm.js.map
